==> net.bluemind.p2.we.settings-4.9.3879.zip: net/bluemind/addressbook/api/gwt/serder/VCardCommunicationsEmailGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.addressbook.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VCardCommunicationsEmailGwtSerDer implements GwtSerDer<net.bluemind.addressbook.api.VCard.Communications.Email> {

    private net.bluemind.addressbook.api.gwt.serder.VCardBasicAttributeGwtSerDer parent = new  net.bluemind.addressbook.api.gwt.serder.VCardBasicAttributeGwtSerDer(); 
	public VCardCommunicationsEmailGwtSerDer( ) {
	}

	@Override
	public net.bluemind.addressbook.api.VCard.Communications.Email deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.addressbook.api.VCard.Communications.Email ret = new net.bluemind.addressbook.api.VCard.Communications.Email();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.Communications.Email ret, JSONObject json) {
		parent.deserializeTo( ret, json);

	}

	@Override
	public JSONValue serialize(net.bluemind.addressbook.api.VCard.Communications.Email o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.Communications.Email o, JSONObject ret) {
		parent.serializeTo( o, ret);

	}
}

==> net.bluemind.p2.we.settings-5.5.3112.zip: net/bluemind/addressbook/api/gwt/serder/VCardCommunicationsEmailGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.addressbook.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VCardCommunicationsEmailGwtSerDer implements GwtSerDer<net.bluemind.addressbook.api.VCard.Communications.Email> {

	private net.bluemind.addressbook.api.gwt.serder.VCardBasicAttributeGwtSerDer parent = new  net.bluemind.addressbook.api.gwt.serder.VCardBasicAttributeGwtSerDer();
	public VCardCommunicationsEmailGwtSerDer( ) {
	}

	@Override
	public net.bluemind.addressbook.api.VCard.Communications.Email deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.addressbook.api.VCard.Communications.Email ret = new net.bluemind.addressbook.api.VCard.Communications.Email();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.Communications.Email ret, JSONObject json) {
		Set<String> propertiesToIgnore = propertiesToIgnore();
		parent.deserializeTo( ret, json, propertiesToIgnore);
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.Communications.Email ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		Set<String> propertiesToIgnore = propertiesToIgnore();
		propertiesToIgnore.addAll(childPropertiesToIgnore);
		parent.deserializeTo( ret, json, propertiesToIgnore);
	}


	@Override
	public JSONValue serialize(net.bluemind.addressbook.api.VCard.Communications.Email o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.Communications.Email o, JSONObject ret) {
		Set<String> propertiesToIgnore = propertiesToIgnore();
		parent.serializeTo( o, ret, propertiesToIgnore);

	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.Communications.Email o, JSONObject ret, Set<String> childPropertiesToIgnore) {
		Set<String> propertiesToIgnore = propertiesToIgnore();
		propertiesToIgnore.addAll(childPropertiesToIgnore);
		parent.serializeTo( o, ret, propertiesToIgnore);

	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
